@@ -39,7 +39,7 @@ extern "C"
 #include <math.h>
 #include <stdlib.h>
 #include <assert.h>
-//#include <string.h>
+#include <string.h>
 #include <Rmath.h>
 #include <string>
 #include <fstream>
@@ -245,7 +245,7 @@ void Matern::Update(unsigned int n, double **X)
     nd = n;
   }
   dist_symm(xDISTx, dim, X, n, PWR);
-  matern_dist_to_K_symm(K, xDISTx, d, nu, bk, nb, nug, n);
+  matern_dist_to_K_symm(K, xDISTx, d, nu, bk, nug, n);
   //delete_matrix(xDISTx);
 }
 
@@ -262,7 +262,7 @@ void Matern::Update(unsigned int n, double **K, double **X)
    
   double ** xDISTx = new_matrix(n, n);
   dist_symm(xDISTx, dim, X, n, PWR);
-  matern_dist_to_K_symm(K, xDISTx, d, nu, bk, nb, nug, n);
+  matern_dist_to_K_symm(K, xDISTx, d, nu, bk, nug, n);
   delete_matrix(xDISTx);
 }
 
@@ -279,7 +279,7 @@ void Matern::Update(unsigned int n1, unsigned int n2, double **K, double **X, do
   
   double **xxDISTx = new_matrix(n2, n1);
   dist(xxDISTx, dim, XX, n1, X, n2, PWR);
-  matern_dist_to_K(K, xxDISTx, d, nu, bk, nb, nug, n1, n2);
+  matern_dist_to_K(K, xxDISTx, d, nu, bk, nug, n1, n2);
   delete_matrix(xxDISTx);
 }
 
@@ -335,9 +335,9 @@ int Matern::Draw(unsigned int n, double **F, double **X, double *Z,
       matern_d_draw_margin(n, col, d_new, d, F, Z, xDISTx, log_det_K, *lambda, Vb, K_new, 
 			   Ki_new, Kchol_new, &log_det_K_new, &lambda_new, Vb_new, bmu_new,  
 			   gp_prior->get_b0(), gp_prior->get_Ti(), gp_prior->get_T(), tau2, 
-			   nug, nu, bk, nb, q_bak/q_fwd, ep->DAlpha(), ep->DBeta(), 
+			   nug, nu, bk, q_bak/q_fwd, ep->DAlpha(), ep->DBeta(), 
 			   gp_prior->s2Alpha(), gp_prior->s2Beta(), (int) lin_new, itemp, 
-			    state);
+			   state);
   }
   
   /* did we accept the new draw? */
@@ -687,7 +687,7 @@ void Matern_Prior::read_double(double *dparams)
 
   /* starting value for the range parameter */
   d = dparams[1];
-  // myprintf(mystdout, "starting range=%g\n", d);
+  // MYprintf(MYstdout, "starting range=%g\n", d);
 
   /* reset dparams to start after the nugget gamlin params */
   dparams += 13;
@@ -698,7 +698,7 @@ void Matern_Prior::read_double(double *dparams)
 
   /* d hierarchical lambda prior parameters */
   if((int) dparams[0] == -1)
-    { fix_d = true; /*myprintf(mystdout, "fixing d prior\n");*/ }
+    { fix_d = true; /*MYprintf(MYstdout, "fixing d prior\n");*/ }
   else {
     fix_d = false;
     get_mix_prior_params_double(d_alpha_lambda, d_beta_lambda, 
@@ -708,7 +708,7 @@ void Matern_Prior::read_double(double *dparams)
 
   /* read the fixed nu parameter */
   nu = dparams[0];
-  // myprintf(mystdout, "fixed nu=%g\n", nu);
+  // MYprintf(MYstdout, "fixed nu=%g\n", nu);
   dparams += 1; /* reset */
 }
 
@@ -730,7 +730,7 @@ void Matern_Prior::read_ctrlfile(ifstream *ctrlfile)
   /* read the d parameter from the control file */
   ctrlfile->getline(line, BUFFMAX);
   d = atof(strtok(line, " \t\n#"));
-  myprintf(mystdout, "starting d=%g\n", d);
+  MYprintf(MYstdout, "starting d=%g\n", d);
     
   /* read d and nug-hierarchical parameters (mix of gammas) */
   ctrlfile->getline(line, BUFFMAX);
@@ -740,7 +740,7 @@ void Matern_Prior::read_ctrlfile(ifstream *ctrlfile)
   ctrlfile->getline(line, BUFFMAX);
   strcpy(line_copy, line);
   if(!strcmp("fixed", strtok(line_copy, " \t\n#")))
-    { fix_d = true; myprintf(mystdout, "fixing d prior\n"); }
+    { fix_d = true; MYprintf(MYstdout, "fixing d prior\n"); }
   else {
     fix_d = false;
     get_mix_prior_params(d_alpha_lambda, d_beta_lambda, line, "d lambda");  
@@ -749,7 +749,7 @@ void Matern_Prior::read_ctrlfile(ifstream *ctrlfile)
   /* read the (fixed) nu parameter */
   ctrlfile->getline(line, BUFFMAX);
   nu = atof(strtok(line, " \t\n#"));
-  myprintf(mystdout, "fixed nu=%g\n", nu);
+  MYprintf(MYstdout, "fixed nu=%g\n", nu);
 }
 
 
@@ -922,25 +922,25 @@ void Matern_Prior::SetBasePrior(Base_Prior *base_prior)
 
 void Matern_Prior::Print(FILE *outfile)
 {
-  myprintf(mystdout, "corr prior: matern\n");
+  MYprintf(MYstdout, "corr prior: matern\n");
 
   /* print nugget stuff first */
   PrintNug(outfile);
 
   /* range parameter */
-  // myprintf(outfile, "starting d=%g\n", d);
+  // MYprintf(outfile, "starting d=%g\n", d);
 
   /* nu, smoothness parameter */
-  myprintf(mystdout, "fixed nu=%g\n", nu);
+  MYprintf(MYstdout, "fixed nu=%g\n", nu);
 
   /* range gamma prior */
-  myprintf(outfile, "d[a,b][0,1]=[%g,%g],[%g,%g]\n", 
+  MYprintf(outfile, "d[a,b][0,1]=[%g,%g],[%g,%g]\n", 
 	   d_alpha[0], d_beta[0], d_alpha[1], d_beta[1]);
   
   /* range gamma hyperprior */
-  if(fix_d) myprintf(outfile, "d prior fixed\n");
+  if(fix_d) MYprintf(outfile, "d prior fixed\n");
   else {
-    myprintf(mystdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
+    MYprintf(MYstdout, "d lambda[a,b][0,1]=[%g,%g],[%g,%g]\n", 
 	     d_alpha_lambda[0], d_beta_lambda[0], d_alpha_lambda[1], 
 	     d_beta_lambda[1]);
   }
